@@ -1,7 +1,7 @@
 //! clap App for command cli
 use clap::{App, Arg};
 
-const VERSION: &str = "0.1.4";
+const VERSION: &str = "0.1.6";
 
 pub fn build_app() -> App<'static> {
     let run_command = App::new("run")
@@ -18,6 +18,14 @@ pub fn build_app() -> App<'static> {
             .index(2)
             .multiple_values(true)
     );
+    let open_command = App::new("open")
+        .about("Open catalog on GitHub")
+        .arg(
+            Arg::new("script")
+                .required(true)
+                .help("script name")
+                .index(1)
+        );
     let deno_command = App::new("deno")
         .about("Deno version management")
         .subcommand(App::new("list")
@@ -25,12 +33,27 @@ pub fn build_app() -> App<'static> {
         )
         .subcommand(App::new("add")
             .about("Install Deno with version")
+            .arg(
+                Arg::new("default")
+                    .long("default")
+                    .takes_value(false)
+                    .help("Set as default version")
+                    .required(false)
+            )
             .arg(Arg::new("version")
                 .required(true)
                 .help("Deno version")
                 .index(1)
             )
         )
+        .subcommand(App::new("default")
+            .about("Set default Deno version")
+            .arg(Arg::new("version")
+                .required(true)
+                .help("Default Deno version for DBang")
+                .index(1)
+            )
+        )
         .subcommand(App::new("delete")
             .about("Delete local installed Deno")
             .arg(Arg::new("version")
@@ -158,6 +181,7 @@ pub fn build_app() -> App<'static> {
                 .required(false),
         )
         .subcommand(run_command)
+        .subcommand(open_command)
         .subcommand(deno_command)
         .subcommand(trust_command)
         .subcommand(install_command)
