@@ -14,6 +14,8 @@ pub struct Artifact {
     #[serde(rename(serialize = "script-ref", deserialize = "script-ref"))]
     pub script_ref: String,
     pub description: Option<String>,
+    #[serde(rename(serialize = "import-map", deserialize = "import-map"))]
+    pub import_map: Option<String>,
     pub deno: Option<String>,
     pub permissions: Option<Vec<String>>,
 }
@@ -35,6 +37,16 @@ impl Artifact {
         };
     }
 
+    pub fn get_import_map_http_url(&self, repo_name: &str) -> String {
+        let import_map = self.import_map.as_ref().unwrap().clone();
+        return if import_map.starts_with("https://") || import_map.starts_with("http://") {
+            import_map
+        } else {
+            let catalog_repo = Catalog::get_full_repo_name(repo_name);
+            format!("https://raw.githubusercontent.com/{}/HEAD/{}", catalog_repo, import_map)
+        };
+    }
+
     pub fn get_deno_permissions(&self) -> Vec<String> {
         if let Some(permissions) = &self.permissions {
             return permissions.iter().map(|x| {
@@ -54,6 +66,10 @@ impl Artifact {
         if let Some(deno_version) = &self.deno {
             return String::from(deno_versions::get_deno_binary(deno_version).to_string_lossy());
         }
+        let default_deno = deno_versions::get_default_deno();
+        if default_deno.exists() {
+            return String::from(default_deno.to_string_lossy());
+        }
         return "deno".to_string();
     }
 }
@@ -171,7 +187,7 @@ fn get_dbang_catalog_url_on_github(catalog_full_name: &str) -> String {
     };
 }
 
-
+#[cfg(test)]
 mod tests {
     use super::*;
 
