@@ -1,11 +1,18 @@
 use std::process::{Command, Output, Stdio};
+use crate::catalog::Artifact;
 
-pub fn run(deno_bin_path: &str, script_name: &str, args: &[&str], permissions: &[String]) -> anyhow::Result<Output> {
-    let output = Command::new(deno_bin_path)
-        .arg("run")
-        .arg("--no-check")
-        .args(permissions)
-        .arg(script_name)
+pub fn run(repo_name: &str, artifact: &Artifact, args: &[&str]) -> anyhow::Result<Output> {
+    let mut command = Command::new(artifact.get_deno_bin_path());
+    command.arg("run").arg("--no-check");
+    if artifact.permissions.is_some() {
+        command.args(artifact.get_deno_permissions());
+    }
+    if artifact.import_map.is_some() {
+        command.arg("--import-map");
+        command.arg(artifact.get_import_map_http_url(repo_name));
+    }
+    let output = command
+        .arg(artifact.get_script_http_url(repo_name))
         .args(args)
         .stdin(Stdio::inherit())
         .stdout(Stdio::inherit())
