@@ -47,6 +47,11 @@ fn main() {
         }
         let artifact_full_name = sub_command_args.value_of("script").unwrap();
         dbang_run(artifact_full_name, &artifact_args, verbose).unwrap();
+    }
+    if sub_command == "open" {
+        let artifact_full_name = sub_command_args.value_of("script").unwrap();
+        let url = format!("https://github.com/{}", artifact_full_name);
+        dbang_utils::open_url(&url).unwrap();
     } else if sub_command == "install" {
         let artifact_full_name = sub_command_args.value_of("script").unwrap();
         let app_name = if let Some(name) = sub_command_args.value_of("name") {
@@ -60,14 +65,17 @@ fn main() {
                 artifact_full_name.to_string()
             }
         };
-        if app_name == "dbang" || app_name == "dbang-shim" {
-            println!("{}", "dbang and dbang-shim are reserved names, please use other names".red());
+        if app_name == "dbang" || app_name.starts_with("dbang-") || app_name == "deno" {
+            println!("{}", "dbang, deno and dbang-* are reserved names, please use other names".red());
             return;
         }
         aliases::add(app_name.clone(), artifact_full_name.to_string()).unwrap();
         //create soft link
         let dbang_shim_path = which("dbang-shim").unwrap();
         let app_link = dbang_bin_dir.join(&app_name);
+        if app_link.exists() {
+            symlink::remove_symlink_file(&app_link).unwrap();
+        }
         symlink::symlink_file(dbang_shim_path, app_link).unwrap();
         println!("{} app installed", app_name);
     } else if sub_command == "uninstall" {
@@ -134,16 +142,25 @@ fn main() {
             };
         } else if deno_sub_command == "add" {
             let mut deno_version = deno_sub_command_args.value_of("version").unwrap().to_string();
+            let as_default = deno_sub_command_args.is_present("default");
             if deno_version.starts_with("v") {
                 deno_version = deno_version[1..].to_string();
             }
-            println!("Begin to install Deno...");
+            println!("Begin to install Deno {} ...", deno_version);
             deno_versions::install(&deno_version).unwrap();
-            println!("Deno installed successfully!");
+            println!("Deno {} installed successfully!", deno_version);
+            if as_default {
+                deno_versions::link_as_default(&deno_version).unwrap();
+                println!("Default deno switched to {}", deno_version);
+            }
         } else if deno_sub_command == "delete" {
             let deno_version = deno_sub_command_args.value_of("version").unwrap();
             deno_versions::delete(deno_version).unwrap();
             println!("Deno deleted successfully!");
+        } else if deno_sub_command == "default" {
+            let deno_version = deno_sub_command_args.value_of("version").unwrap();
+            deno_versions::link_as_default(deno_version).unwrap();
+            println!("Default deno switched to {}", deno_version);
         } else {
             println!("{}", "Unknown subcommand");
         }
@@ -169,8 +186,6 @@ fn main() {
         } else {
             println!("{}", "Unknown subcommand");
         }
-    } else {
-        println!("{}", "Unknown subcommand");
     }
 }
 
@@ -222,10 +237,7 @@ fn dbang_run(artifact_full_name: &str, artifact_args: &[&str], verbose: bool) ->
             println!("[dbang] script permissions:  {}", permissions.join(","));
         }
     }
-    deno_cli::run(&artifact.get_deno_bin_path(), &script_url,
-                  artifact_args,
-                  &permissions,
-    )?;
+    deno_cli::run(repo_name, &artifact, artifact_args)?;
     Ok(())
 }
 
